Module aws

Module aws 

AWS secret manager

Secret manager backed by AWS secrets manager. Inherits the loaded SdkConfig and all configuration provided to it.

Environment Variables

  • DOCBOX_SECRETS_ENDPOINT - URL to use when using a custom secrets manager endpoint
  • DOCBOX_SECRETS_ACCESS_KEY_ID - Access key ID when using a custom secrets manager endpoint
  • DOCBOX_SECRETS_ACCESS_KEY_SECRET - Access key secret when using a custom secrets manager endpoint

Structs

AwsSecretManager
AWS secrets manager backed secrets
AwsSecretManagerConfig
Config for the JSON secret manager

Enums

AwsSecretError
Errors that could occur when working with AWS secret manager
AwsSecretsEndpoint
Endpoint to use for secrets manager operations
AwsSecretsManagerConfigError
Errors that could occur when loading the AWS configuration