Module memory

Module memory 

Memory secret manager

In-memory secret manager for use within tests and local development environments where a full secret manager is not needed

Environment Variables

  • DOCBOX_SECRET_MANAGER_MEMORY_DEFAULT - Optional default secret value to provide when missing the secret
  • DOCBOX_SECRET_MANAGER_MEMORY_SECRETS - JSON encoded hashmap of available secrets

Structs

MemorySecretManager
In-memory secret manager
MemorySecretManagerConfig
Secrets manager backed by memory

Enums

MemorySecretManagerConfigError
Errors that could occur with the memory secrets manager config loaded from the current environment

Type Aliases

MemorySecretError
Memory secret manager cannot fail