AWS secret manager
Secret manager backed by AWS secrets manager. Inherits the loaded SdkConfig and all configuration provided to it.
Environment Variables
DOCBOX_SECRETS_ENDPOINT- URL to use when using a custom secrets manager endpointDOCBOX_SECRETS_ACCESS_KEY_ID- Access key ID when using a custom secrets manager endpointDOCBOX_SECRETS_ACCESS_KEY_SECRET- Access key secret when using a custom secrets manager endpoint
Structs
- AwsSecret
Manager - AWS secrets manager backed secrets
- AwsSecret
Manager Config - Config for the JSON secret manager
Enums
- AwsSecret
Error - Errors that could occur when working with AWS secret manager
- AwsSecrets
Endpoint - Endpoint to use for secrets manager operations
- AwsSecrets
Manager Config Error - Errors that could occur when loading the AWS configuration