Memory secret manager
In-memory secret manager for use within tests and local development environments where a full secret manager is not needed
Environment Variables
DOCBOX_SECRET_MANAGER_MEMORY_DEFAULT- Optional default secret value to provide when missing the secretDOCBOX_SECRET_MANAGER_MEMORY_SECRETS- JSON encoded hashmap of available secrets
Structs
- Memory
Secret Manager - In-memory secret manager
- Memory
Secret Manager Config - Secrets manager backed by memory
Enums
- Memory
Secret Manager Config Error - Errors that could occur with the memory secrets manager config loaded from the current environment
Type Aliases
- Memory
Secret Error - Memory secret manager cannot fail